;;*****************************************************************************
;;*****************************************************************************
;;  FILENAME: DelSigINT.asm
;;   Version: 1.2, Updated on 2009/10/9 at 10:6:29
;;  Generated by PSoC Designer 5.0.1127.0
;;
;;  DESCRIPTION: Assembler interrupt service routine for the Delta-Sigma ADC
;;               User Module based on the Type 2 Decimator. This code works for
;;               both the first and second-order modulator topologies where
;;               the decimation rate requires no extra shift of 8-bit data
;;               (or narrower) in software.
;;-----------------------------------------------------------------------------
;;  Copyright (c) Cypress Semiconductor 2009. All Rights Reserved.
;;*****************************************************************************
;;*****************************************************************************

include "m8c.inc"
include "memory.inc"
include "DelSig.inc"


;-----------------------------------------------
;  Global Symbols
;-----------------------------------------------

export _DelSig_ADConversion_ISR
export _DelSig_cResult
export  DelSig_cResult
export _DelSig_bfStatus
export  DelSig_bfStatus


;-----------------------------------------------
; Variable Allocation
;-----------------------------------------------
AREA InterruptRAM (RAM, REL, CON)

_DelSig_cResult:
 DelSig_cResult:                   blk 1             ;ADC output value
_DelSig_bfStatus:
 DelSig_bfStatus:                  blk 1             ;Data Valid Flag


;-----------------------------------------------
;  Private Symbols
;-----------------------------------------------
MSB:                               equ 0
LSB:                               equ 1
RES:                               equ 8
UMAX:                              equ (1<<RES) - 1  ; 2^RES - 1


;@PSoC_UserCode_INIT@ (Do not change this line.)
;---------------------------------------------------
; Insert your custom declarations below this banner
;---------------------------------------------------

;------------------------
; Includes
;------------------------

;------------------------
; Exports
;------------------------

;------------------------
; Constant Definitions
;------------------------

;------------------------
; Variable Allocation
;------------------------

;---------------------------------------------------
; Insert your custom declarations above this banner
;---------------------------------------------------
;@PSoC_UserCode_END@ (Do not change this line.)


AREA UserModules (ROM, REL, CON)

;;=============================================================================
;;  FUNCTION NAME: _DelSig_ADConversion_ISR:
;;=============================================================================
;;
_DelSig_ADConversion_ISR:
   push  A
   mov   A, reg[DEC_DH]               ; Is value == 2^RES?
   jz    .NoOverflow                  ;    No, data is in normal range
   mov   A, reg[DEC_DL]
   mov   A, UMAX                      ;   Yes, limit to 2^RES - 1
   jmp   .ConversionReady

.NoOverflow:
   mov   A, reg[DEC_DL]

.ConversionReady:
IF DelSig_2S_COMPLEMENT
   ; Internal hardware format is unsigned; convert so zero is half scale
   sub   A, (UMAX+1)>>1
ENDIF
   mov [DelSig_cResult],  A
   mov [DelSig_bfStatus], DelSig_DATA_READY_BIT                ; Set valid data flag


   ;@PSoC_UserCode_BODY@ (Do not change this line.)
   ;---------------------------------------------------
   ; Insert your custom code below this banner
   ;---------------------------------------------------


   ;---------------------------------------------------
   ; Insert your custom code above this banner
   ;---------------------------------------------------
   ;@PSoC_UserCode_END@ (Do not change this line.)
   pop   A
   reti

; end of file DelSigINT.asm
